Documentation
¶
Index ¶
- Constants
- type Clock
- func (c *Clock) After(d Duration) <-chan Time
- func (c *Clock) AfterFunc(d Duration, f func()) *Timer
- func (*Clock) Hours(n float64) Duration
- func (*Clock) Microseconds(n int64) Duration
- func (*Clock) Milliseconds(n int64) Duration
- func (*Clock) Minutes(n float64) Duration
- func (*Clock) Nanoseconds(n int64) Duration
- func (c *Clock) NewTicker(d Duration) *Ticker
- func (c *Clock) NewTimer(d Duration) *Timer
- func (c *Clock) Now() (now Time)
- func (*Clock) ParseDuration(s string) (Duration, error)
- func (*Clock) Seconds(n float64) Duration
- func (c *Clock) Set(now Time)
- func (c *Clock) Since(t Time) Duration
- func (c *Clock) Sleep(d Duration)
- func (c *Clock) Step(dt Duration)
- func (c *Clock) Tick(d Duration) <-chan Time
- func (c *Clock) Until(t Time) Duration
- type Duration
- type Ticker
- type Time
- type Timer
Constants ¶
const ( Nanosecond = time.Nanosecond Microsecond = time.Microsecond Millisecond = time.Millisecond Second = time.Second Minute = time.Minute Hour = time.Hour )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clock ¶
type Clock struct {
// contains filtered or unexported fields
}
func (*Clock) Microseconds ¶
func (*Clock) Milliseconds ¶
func (*Clock) Nanoseconds ¶
func (*Clock) Set ¶
If any timers are active, a value of `now` earlier than the previous setting may lead to undefined behavior.
Click to show internal directories.
Click to hide internal directories.